<?php

namespace DsbNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class DashboardTAController{
    
    protected $crudService;
    protected $service;
    
    public function __construct($connection, $environment, $util, $crudService, $service) {
        $this->crudService     = $crudService;
        $this->connection      = $connection;
        $this->environment     = $environment;
        $this->util            = $util;
        $this->service         = $service;
    }
    
    public function previousDayAFDeliveryTA(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        
        $data = $this->crudService->getFilteredDataSet('previousDayAFDeliveryTA', $conditions)->getRows();
        $response->addDataSet(new DataSet("previousDayAFDeliveryTA", $data));
    }
    
    public function afApprovalTracking(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        
        $data = $this->crudService->getFilteredDataSet('afApprovalTracking', $conditions)->getRows();
        $response->addDataSet(new DataSet("afApprovalTracking", $data));
    }
    
    public function aFDeliveryLastWeekTA(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        
        $data = $this->crudService->getFilteredDataSet('aFDeliveryLastWeekTA', $conditions)->getRows();
        $response->addDataSet(new DataSet("aFDeliveryLastWeekTA", $data));
    }
    
    public function aFDeliveryLastWeekGrid(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getParameters();
        $variables = array();
        
        array_push($variables ,
            array (
                "columnName" => "SELECTED",
                "operator" => "=",
                "value" => $filter['SELECTED']
            )
        );
        $filter = $request->getFilterCriteria()->getConditions();
        
        $data = $this->crudService->getFilteredDataSet('aFDeliveryLastWeekGrid', array_merge($conditions, $variables))->getRows();
        $response->addDataSet(new DataSet("aFDeliveryLastWeekGrid", $data));
    }
    
    public function AFGeneral(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getFilterCriteria()->getConditions();
        
        $data = $this->crudService->getFilteredDataSet('AFGeneral', $conditions)->getRows();
        $response->addDataSet(new DataSet("AFGeneral", $data));  
    }
    
    public function drillDownAFGeneralFirstLevel($conditions, $idRecebimento, $response) {
        $params = [
                'CDFILCENTCMP' => $conditions[0]['value'],
                'IDCONFRECEBIMENTO' => $idRecebimento
        ];
        try {
            $data = $this->service->drillDownAFGeneralFirstLevel($params);
            $response->addDataSet(new DataSet("drillDownAFGeneral", $data));
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    private function drillDownAFGeneralSecondLevel($conditions, $idRecebimento, $operador, $response){
        $params = array(
            "CDOPERADOR" => $operador,
            "CDFILCENTCMP" => $conditions[0]['value'],
            "IDCONFRECEBIMENTO" => $idRecebimento
        );
        try {
            $data = $this->service->drillDownAFGeneralSecondLevel($params);
            $response->addDataSet(new DataSet("drillDownAFGeneral", $data));
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function drillDownAFGeneralThirdLevel($conditions, $idRecebimento, $operador, $regiao, $response) {
        $params = array(
            "NMREGIAOGEO" => $regiao,
            "CDOPERADOR" => $operador,
            "CDFILCENTCMP" => $conditions[0]['value'],
            "IDCONFRECEBIMENTO" => $idRecebimento
        );
        try {
            $data = $this->service->drillDownAFGeneralThirdLevel($params);
            $response->addDataSet(new DataSet("drillDownAFGeneral", $data));
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    public function drillDownAFGeneral(Request\Filter $request, Response $response) {
        $data = $request->getParameters();
        $IDCONFRECEBIMENTO = isset($data['IDCONFRECEBIMENTO'])? $data['IDCONFRECEBIMENTO'] : null;
        $CODOPERADOR = isset($data['operador'])? $data['operador']: null;
        $REGIAO = isset($data['regiao'])? $data['regiao'] : null;
        
        
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $level = $data['level'];
        switch($level){
            case 0:
                $this->drillDownAFGeneralFirstLevel($conditions, $IDCONFRECEBIMENTO, $response);
                break;
            case 1:
                $this->drillDownAFGeneralSecondLevel($conditions, $IDCONFRECEBIMENTO, $CODOPERADOR, $response);
                break;
            case 2:
                $this->drillDownAFGeneralThirdLevel($conditions, $IDCONFRECEBIMENTO, $CODOPERADOR, $REGIAO, $response);
        }
    }
    
    /**
     * This function retrieves and filters data for the AFGeneralTAGrid.
     *
     * It first prepares conditions based on the parameters array ($params) which currently contains
     * 'CDFILCENTCMP'. The conditions are prepared using the utility method `prepareConditions`.
     * 
     * The function then populates an array ($variables) with filtering criteria retrieved from the
     * front-end. These filters are applied to columns: 'OPERADOR', 'IDCONFRECEBIMENTO', 'NMESTADO', 
     * and 'NMREGIAOGEO'.
     *
     * The merged array of conditions and variables is passed to the `getFilteredDataSet` method
     * of the `crudService`, which retrieves the filtered data from the 'AFGeneralTAGrid' table.
     * 
     * The resulting data is added to the response as a dataset named 'AFGeneralTAGridGroup'.
     *
     * @param Request\Filter $request The object that receives data from the caller.
     * @param Response $response The object that sends data back to the caller.
     *
     * @return void
     *
     * @throws Exception If an error occurs during data retrieval.
     * 
     * @access public
     * @author Arthur Gustavo
     */
    
    public function AFGeneralTAGrid(Request\Filter $request, Response $response) {
        $params = ['CDFILCENTCMP'];
        $conditions = $this->util->prepareConditions($params);
        $filter = $request->getParameters();
        $variables = array();
        
        array_push($variables ,
            array (
                "columnName" => "OPERADOR",
                "operator" => "=",
                "value" => $filter['OPERADOR']
            ),
            array (
                "columnName" => "IDCONFRECEBIMENTO",
                "operator" => "=",
                "value" => $filter['IDCONFRECEBIMENTO']
            ),
            array (
                "columnName" => "NMESTADO",
                "operator" => "=",
                "value" => $filter['NMESTADO']
            ),
            array (
                "columnName" => "NMREGIAOGEO",
                "operator" => "=",
                "value" => $filter['NMREGIAOGEO']
            )
        );
        
        $data = $this->crudService->getFilteredDataSet('AFGeneralTAGrid', array_merge($conditions, $variables))->getRows();
        $response->addDataSet(new DataSet("AFGeneralTAGridGroup", $data));
    }
}