<?php
namespace DsbNext\Services;

class DashboardTAControllerService {
    
    public function __construct($entityManager, $environment){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    /**
     * These 3 functions perform the drilldown of the AFGeneral chart.
     * 
     * They receive parameters, which are passed in the function of the same name in DashboardTaController.
     * 
     * A query is made with the indicated parameters, which returns the values to the DashboardTaController 
     * where they are added to the dataset.
     * 
     * @access public
     * @author Arthur Gustavo
     */
    
    public function drillDownAFGeneralFirstLevel($params) {
        $query = "
            SELECT 
                    NMOPERADOR AS LABEL,
                    COUNT(NRAUTOFORN) AS VALUE,
                    NVL(IDCONFRECEBIMENTO, 'X') AS IDCONFRECEBIMENTO, 
                    CDOPERADOR
                FROM 
                (
                    SELECT * 
                      FROM DM_TRACKING_AF
                     WHERE CDFILCENTCMP = :CDFILCENTCMP
                       AND DTPROGENTAF BETWEEN TRUNC(FIRST_DAY(SYSDATE)) AND TRUNC(SYSDATE - 1)
                       AND NVL(IDCONFRECEBIMENTO, 'X') = :IDCONFRECEBIMENTO
                )
                GROUP BY 
                    IDCONFRECEBIMENTO,
                    CDOPERADOR,
                    NMOPERADOR
                ORDER BY 
                    CDOPERADOR
        ";
        try{
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            return $result;
        }catch(Exception $e) {
          throw $e; 
        }
    }
    
    public function drillDownAFGeneralSecondLevel($params) {
        $query = "
            SELECT
                NMREGIAOGEO AS LABEL,
                COUNT(NRAUTOFORN) AS VALUE,
                NVL(IDCONFRECEBIMENTO,'X') AS IDCONFRECEBIMENTO,
                CDOPERADOR,
                NMREGIAOGEO AS REGIAO
            FROM
            (
                SELECT * 
                  FROM DM_TRACKING_AF
                 WHERE CDFILCENTCMP = :CDFILCENTCMP
                   AND DTPROGENTAF BETWEEN TRUNC(FIRST_DAY(SYSDATE)) AND TRUNC(SYSDATE - 1)
                   AND CDOPERADOR = :CDOPERADOR
                   AND NVL(IDCONFRECEBIMENTO, 'X') = :IDCONFRECEBIMENTO
            )
            GROUP BY
                NMREGIAOGEO,
                CDOPERADOR,
                IDCONFRECEBIMENTO
            ORDER BY
                NMREGIAOGEO
        ";
        try{
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            return $result;
        }catch(Exception $e) {
          throw $e; 
        }
    }
    
    public function drillDownAFGeneralThirdLevel($params) {
        $query = "
                SELECT
                    NMESTADO AS LABEL,
                    COUNT(NRAUTOFORN) AS VALUE,
                    NVL(IDCONFRECEBIMENTO,'X') AS IDCONFRECEBIMENTO,
                    CDOPERADOR,
                    NMREGIAOGEO AS REGIAO,
                    NMESTADO
                FROM
                (
                    SELECT * 
                      FROM DM_TRACKING_AF
                     WHERE CDFILCENTCMP = :CDFILCENTCMP
                       AND DTPROGENTAF BETWEEN TRUNC(FIRST_DAY(SYSDATE)) AND TRUNC(SYSDATE - 1)
                       AND CDOPERADOR = :CDOPERADOR
                       AND NVL(IDCONFRECEBIMENTO,'X') = :IDCONFRECEBIMENTO
                       AND NMREGIAOGEO = :NMREGIAOGEO
                )
                GROUP BY
                    NMESTADO,
                    NMREGIAOGEO,
                    CDOPERADOR,
                    IDCONFRECEBIMENTO
                ORDER BY
                    NMESTADO
            ";
        try{
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            return $result;
        }catch(Exception $e) {
          throw $e; 
        }
    }
}