<?php
namespace DsbNext\Services;

class ParametersDashboardService {
    
    public function __construct($entityManager, $environment){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    public function beginTransaction() {
        $this->connection->beginTransaction();
    }
    
    public function commit() {
        $this->connection->commit();
    }
    
    public function rollback() {
      $this->connection->rollback();
    }
  
    public function insertProfile($params) {
        $query = "INSERT INTO PERFACLPAINEL 
                              (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH,  NRORG) 
                      VALUES 
                              (:NRPERFACLPAINEL, :NRPERFILACESSO,  :NRPAINEL, :CDFILIAL, :IDPADRAODASH, :NRORG)";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        };
    }
  
    public function deleteProfileAccess($params) {
        $query = "DELETE 
                    FROM PERFACLPAINEL
                   WHERE
                         NRPERFACLPAINEL = :NRPERFACLPAINEL";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        };
    }
  
    public function rowsProfileUpdate($params) {
        $query = "UPDATE PERFACLPAINEL
                     SET IDPADRAODASH = :IDPADRAODASH
                   WHERE NRPERFACLPAINEL = :NRPERFACLPAINEL
                     AND CDFILIAL = :CDFILIAL";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        };
    }
  
    public function insertIndicpanel($params){
        $query = 
            "INSERT INTO 
                    INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                         VALUES (:NRINDICPAINEL, :NRPERFACLPAINEL, :NRINDICADORTF, :IDVISUINDIC, :NRORG)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex) {
            throw $ex;
        };
    }
    
    public function updateIndicpanel($params) {
        $query = "UPDATE INDICPAINEL
                    SET
                        IDVISUINDIC = :IDVISUINDIC
                  WHERE
                        NRINDICPAINEL = :NRINDICPAINEL AND
                        NRORG = :NRORG";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex) {
            throw $ex;
        };  
    }
    
    public function deleteOperatorEx($params, $cdoperador){
        $in = '(' . implode(',', $cdoperador) .')';
        $query = "
            DELETE
              FROM INDICPAINEXCOPER I
             WHERE I.NRINDICPAINEXCOPER IN (
                SELECT IEX.NRINDICPAINEXCOPER
                  FROM INDICPAINEXCOPER IEX JOIN INDICPAINEL IP ON IEX.NRINDICPAINEL = IP.NRINDICPAINEL
                                         JOIN PERFACLPAINEL P ON P.NRPERFACLPAINEL = IP.NRPERFACLPAINEL
                 WHERE P.NRPAINEL = :NRPAINEL
                   AND P.CDFILIAL = :CDFILIAL
                   AND P.NRPERFILACESSO = :NRPERFILACESSO
                   AND IEX.CDOPERADOR IN " . $in. ")";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function deleteOperatorExInd($nrindicpainexoper){
        $in = '(' . implode(',', $nrindicpainexoper) .')';
        $query = "
            DELETE
              FROM INDICPAINEXCOPER 
             WHERE NRINDICPAINEXCOPER IN " . $in;
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute();
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function countIndicatortf($params){
        $query =
               "SELECT COUNT(1) INDICADORESTF
                  FROM INDICADORTF I
                 WHERE I.NRINDICADORTF NOT IN (SELECT NRINDICADORTF 
                                                 FROM INDICPAINEL IP
                                                WHERE NRPERFACLPAINEL = :NRPERFACLPAINEL)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            return $stmt->fetchAll()[0]["INDICADORESTF"];
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function insertAllIndicpanel($params){
        $query = 
            "INSERT INTO INDICPAINEL (NRINDICPAINEL, NRINDICADORTF, NRPERFACLPAINEL, IDVISUINDIC, NRORG)
                        SELECT :NRINDICPAINEL + ROWNUM, NRINDICADORTF, :NRPERFACLPAINEL, 'S', :NRORG
                          FROM INDICADORTF I
                         WHERE NOT EXISTS (SELECT 1 
                                            FROM INDICPAINEL IP JOIN PERFACLPAINEL P ON IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                           WHERE P.NRPAINEL = :NRPAINEL
                                             AND IP.NRINDICADORTF = I.NRINDICADORTF
                                             AND IP.NRPERFACLPAINEL = :NRPERFACLPAINEL)";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function checkedPanel(){
        $query = 
            "SELECT NRPAINEL
               FROM (
                    SELECT 1 PAINEL1, 11 PAINEL11, 22 PAINEL22, 33 PAINEL33
                    FROM DUAL
                )
                UNPIVOT
                (
                    NRPAINEL
                    FOR NMPAINEL IN (PAINEL1, PAINEL11, PAINEL22, PAINEL33)
                )
                MINUS
                SELECT NRPAINEL
                FROM PAINEL
                WHERE NRPAINEL IN (1,11,22,33)";
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute();
            return $stmt->fetchAll();
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function countIndicator($params){
        $query =
               "SELECT COUNT(*) INDICADORES
                  FROM INDICADORTF I
                 WHERE I.NRPAINEL = :NRPAINEL";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            return $stmt->fetchAll()[0]["INDICADORES"];
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
     public function insertExOperatorPanel($params){
        $query = "
            INSERT INTO INDICPAINEXCOPER
              (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
              SELECT :NRINDICPAINEXOPER + ROWNUM, IP.NRINDICPAINEL, :CDOPERADOR, :NRORG 
                FROM INDICPAINEL IP JOIN PERFACLPAINEL P ON IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                    JOIN INDICADORTF I ON I.NRINDICADORTF = IP.NRINDICADORTF
                                                      AND P.NRPAINEL = I.NRPAINEL 
               WHERE P.NRPERFACLPAINEL = :NRPERFACLPAINEL
                 AND NOT EXISTS (SELECT 1 
                                   FROM INDICPAINEXCOPER IEX JOIN INDICPAINEL IPEX ON IEX.NRINDICPAINEL = IPEX.NRINDICPAINEL
                                                             JOIN PERFACLPAINEL PEX ON PEX.NRPERFACLPAINEL = IPEX.NRPERFACLPAINEL
                                  WHERE PEX.NRPAINEL = P.NRPAINEL 
                                    AND PEX.NRPERFILACESSO = P.NRPERFILACESSO
                                    AND IEX.CDOPERADOR = :CDOPERADOR
                                    AND PEX.CDFILIAL = :CDFILIAL
                                    AND I.NRINDICADORTF = IPEX.NRINDICADORTF)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function insertExOperatorIndicator($params){
        $query = 
            "INSERT INTO 
                    INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                              VALUES (:NRINDICPAINEXCOPER, :NRINDICPAINEL, :CDOPERADOR, :NRORG)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function insertPanel($nrpainel, $params){
        try {
            foreach($nrpainel as $numPanel){
                switch ($numPanel["NRPAINEL"]) {
                    case 1:
                        $query = "INSERT INTO PAINEL (NRPAINEL, NMPAINEL, CDPAINEL, NRORG) VALUES (1, 'Painel de Indicadores - Gerente de Unidade', 'PLA99000', :NRORG)";
                        break;
                    case 11:
                        $query = "INSERT INTO PAINEL (NRPAINEL, NMPAINEL, CDPAINEL, NRORG) VALUES (11, 'Painel de Indicadores - Gerente Operacional/Supervisor', 'PLA99300', :NRORG)";
                        break;
                    case 22:
                        $query = "INSERT INTO PAINEL (NRPAINEL, NMPAINEL, CDPAINEL, NRORG) VALUES (22, 'Análise de Custo - Tendência', 'PLA99800', :NRORG)";
                        break;
                    case 33:
                        $query = "INSERT INTO PAINEL (NRPAINEL, NMPAINEL, CDPAINEL, NRORG) VALUES (33, 'Tracking de AF', 'SUP99000', :NRORG)";
                        break;
                    default:
                        echo "Resposta inválida.";
                        break;
                }
                $stmt = $this->connection->prepare($query);
                $stmt->execute($params);
            } 
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function checkIndicator(){
        try {
                $arrayInsert=[
                    1=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (1,  'Dias de Estoque', 1)",
                    2=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (2,  'Data de Processamento', 1)",
                    3=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (3,  'Dias de Atraso', 1)",
                    4=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (4,  'Valor de Ajuste', 1)",
                    5=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (5,  'Valor de Solicitações Extras', 1)",
                    6=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (6,  'Análise de Custo', 1)",
                    7=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (7,  'Análise de PU do dia', 1)",
                    8=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (8,  'Inflação', 1)",
                    9=> "INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (9,  'Entregas de Hoje', 1)",
                    10=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (10, 'Resumo DRO', 1)",
                    11=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (11, 'Produtos sem Movimentação há mais de 30 dias', 1)",
                    12=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (12, 'Análise de Custo', 11)",
                    13=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (13, 'Percentual de Ajuste  Consumo', 11)",
                    14=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (14, 'Resumo DRO', 11)",
                    15=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (15, 'Dias de Estoque', 11)",
                    16=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (16, 'Acompanhamento de Efetivos', 22)",
                    17=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (17, 'Comparativo de Custo', 22)",
                    18=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (18, 'Análise de Custo - Acumulado até', 1)",
                    19=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (19, 'Desvio de Consumo', 1)",
                    20=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (20, 'Próxima Liberação de Cardápio', 1)",
                    21=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (21, 'Dias para Aprovação de Cardápio', 1)",
                    22=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (22, 'Impacto Financeiro', 1)",
                    23=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (23, 'Lançamentos Pendentes (XML x NF)', 1)",
                    24=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (24, 'Orçamento do Consumo', 1)",
                    25=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (25, 'Orçamento do Período', 1)",
                    26=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (26, 'Resumo DRO - Grade', 1)",
                    27=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (27, 'Consumo Workflow', 1)",
                    28=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (28, 'Acompanhamento de Aprovação de AF', 33)",
                    29=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (29, 'Entrega Total de AF', 33)",
                    30=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (30, 'Entrega de AF - Últimos 7 dias', 33)",
                    31=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (31, 'Entrega de AF - Mês atual', 33)",
                    32=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (32, 'Entrega de AF - Anual', 33)",
                    33=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (33, 'Entrega de AF - Mes Atual (Comprador)', 33)",
                    34=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (34, 'AFs Confirmadas pelo Fornecedor', 33)",
                    35=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (35, 'Media de Atraso do Lancamento de NF', 33)",
                    36=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (36, 'Orçamento de Despesa', 1)",
                    37=>"INSERT INTO INDICADORTF (NRINDICADORTF, DSINDICADOR, NRPAINEL) VALUES (37, 'Despesa Workflow', 1)"
                ];  
            $length = count($arrayInsert);
            $params = [
                ':LENGTH' =>  $length
            ];
            $query = "SELECT ROWNUM SEQUENCIAL FROM DUAL CONNECT BY LEVEL <= :LENGTH
                       MINUS
                      SELECT NRINDICADORTF SEQUENCIAL FROM INDICADORTF";
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
		    $result = $stmt->fetchAll();
		    
		    if(count($result) > 0){
		       $this->insertIdicator($arrayInsert, $result);
		    }
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function insertIdicator ($arrayInsert, $result){
        try {
            foreach($result as $row){
                $stmt = $this->connection->prepare($arrayInsert[$row['SEQUENCIAL']]);
                $stmt->execute();
            }
        } catch (Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        } 
    }
    
    public function checkLabelName($params)
    {
        $query =
            "SELECT
                    IP.NRINDICPAINEL,
                    I.NRINDICADORTF,
                    :NRPERFACLPAINEL AS NRPERFACLPAINEL,
                    I.DSINDICADOR,
                    I.NRORG,
                    NVL(IP.IDVISUINDIC, 'S') AS IDVISUINDIC
                FROM
                    INDICADORTF I
                LEFT JOIN
                    INDICPAINEL IP ON I.NRINDICADORTF = IP.NRINDICADORTF
                    AND IP.NRPERFACLPAINEL = :NRPERFACLPAINEL
                WHERE
                    I.NRPAINEL = :NRPAINEL
                ORDER BY
                    I.NRINDICADORTF";
    
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            return $result;
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function validateDisabledInput($params)
    {
        $query =
            "SELECT
                    *
               FROM
                    (
                        SELECT
                            'A'        AS ORDEM,
                            ''         CDFILIAL_VISIVEL,
                            'P'        CDFILIAL,
                            'P PADRAO' CDNMFILIAL,
                            'PADRÃO'   NMFILIAL,
                            P.NRORG,
                            'N'        IDCNTRRESC
                        FROM
                            DUAL,
                            PARAMGERAL P
                        UNION
                        SELECT
                            'B'             AS ORDEM,
                            FO.CDFILIAL     CDFILIAL_VISIVEL,
                            FO.CDFILIAL     CDFILIAL,
                            ( FO.CDFILIAL
                              || ' - '
                              || F.NMFILIAL ) CDNMFILIAL,
                            F.NMFILIAL,
                            F.NRORG,
                            F.IDCNTRRESC
                        FROM
                            FILIOPER    FO,
                            FILIAL      F,
                            PARAMFILIAL PF
                        WHERE
                            ( ( FO.CDOPERADOR = :CDOPERADOR )
                              OR ( NVL(:CDOPERADOR, 'T') = 'T' ) )
                            AND FO.CDFILIAL = F.CDFILIAL
                            AND F.IDCNTRRESC = 'N'
                            AND PF.CDFILIAL = F.CDFILIAL
                            AND F.CDFILIAL <> :CDFILIAL
                    )
                ORDER BY
                    ORDEM,
                    CDFILIAL";
    
        try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
            $result = $stmt->fetchAll();
            return $result;
        } catch (Exception $ex) {
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function deleteAllUnit($params){
        $query = "DELETE
                    FROM PERFACLPAINEL
                   WHERE CDFILIAL <> :CDFILIAL
                     AND NRORG = :NRORG
                     AND NRPAINEL = NVL(:NRPAINEL, NRPAINEL)";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
       } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function deleteParameterUnit($params){
        $delete = "DELETE
                     FROM INDICPAINEL I
                    WHERE I.NRPERFACLPAINEL IN (SELECT P.NRPERFACLPAINEL
                                                  FROM PERFACLPAINEL P
                                                 WHERE EXISTS (SELECT 1
                                                                 FROM LISTA L
                                                                WHERE L.CDLISTA = P.CDFILIAL
                                                                  AND L.NRLISTA = :NRLISTA
                                                                  AND L.NRORG = :NRORG)
                                                   AND P.NRORG = :NRORG
                                                   AND P.NRPAINEL = NVL(:NRPAINEL, P.NRPAINEL)
                                              GROUP BY P.NRPERFACLPAINEL)";
        
        $query = "DELETE
                    FROM PERFACLPAINEL P
                   WHERE EXISTS (SELECT 1
                                   FROM LISTA L
                                  WHERE L.CDLISTA = P.CDFILIAL
                                    AND L.NRLISTA = :NRLISTA
                                    AND L.NRORG = :NRORG)
                     AND P.NRORG = :NRORG
                     AND P.NRPAINEL = NVL(:NRPAINEL, P.NRPAINEL)";
       try {
            $stmtDelete = $this->connection->prepare($delete);
            $stmtDelete->execute($params);
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
     public function insertReplicate($params){
        $query = "
            DECLARE V_SEQPERFACLPAINEL NUMBER;
                    V_SEQINDICPAINEL   NUMBER;
                    V_SEQINDICPAINEXCOPER NUMBER;
                    V_COMMIT           NUMBER;
                    V_QUANT            NUMBER;
            BEGIN
               V_COMMIT := 0;
               V_QUANT := 0;
               
               FOR C_LISTA IN (SELECT L.CDLISTA
                                 FROM LISTA L
                                WHERE NRLISTA = :NRLISTA
                                  AND 'T' <> :NRLISTA
                                UNION ALL
                               SELECT F.CDFILIAL
                                 FROM FILIAL F
                                WHERE 'T' = :NRLISTA
                                  AND F.CDFILIAL <> :CDFILIAL
                                  AND NVL(F.IDCNTRRESC,'N') = 'N') LOOP
                                
                 UPDATE PARAMFILIAL
                    SET IDUTLDSBTPADRAO = (SELECT P.IDUTLDSBTPADRAO
                                             FROM PARAMFILIAL P
                                            WHERE P.CDFILIAL = :CDFILIAL)
                  WHERE CDFILIAL = C_LISTA.CDLISTA;
                
                  SELECT COUNT(1)
                    INTO V_QUANT
                    FROM PERFACLPAINEL P
                   WHERE P.CDFILIAL = :CDFILIAL
                     AND P.NRORG = :NRORG;
                  
                  NOVO_CODIGO('PERFACLPAINEL',V_SEQPERFACLPAINEL, V_QUANT);
                  
                  INSERT INTO PERFACLPAINEL (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH, NRORG)
                       SELECT V_SEQPERFACLPAINEL+ROWNUM-1, P.NRPERFILACESSO, P.NRPAINEL, C_LISTA.CDLISTA, P.IDPADRAODASH, P.NRORG
                         FROM PERFACLPAINEL P
                        WHERE P.CDFILIAL = :CDFILIAL
                          AND P.NRORG = :NRORG;
                          
                  FOR C_PERFACLPAINEL IN (SELECT P.NRPERFACLPAINEL, O.NRPERFACLPAINEL NRORIGEM
                                            FROM PERFACLPAINEL P, PERFACLPAINEL O
                                           WHERE P.CDFILIAL = C_LISTA.CDLISTA
                                             AND P.NRORG = :NRORG
                                             AND P.NRPERFILACESSO = O.NRPERFILACESSO
                                             AND P.NRPAINEL = O.NRPAINEL
                                             AND O.CDFILIAL = :CDFILIAL) LOOP
                      SELECT COUNT(1)
                        INTO V_QUANT
                        FROM PERFACLPAINEL P, INDICPAINEL IP
                       WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                         AND IP.NRPERFACLPAINEL = C_PERFACLPAINEL.NRORIGEM
                         AND P.CDFILIAL = :CDFILIAL
                         AND P.NRORG = :NRORG;
                      
                      NOVO_CODIGO('INDICPAINEL',V_SEQINDICPAINEL, V_QUANT);
                       
                      INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                           SELECT V_SEQINDICPAINEL+ROWNUM-1, C_PERFACLPAINEL.NRPERFACLPAINEL, IP.NRINDICADORTF, IP.IDVISUINDIC, IP.NRORG
                             FROM PERFACLPAINEL P, INDICPAINEL IP
                            WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                              AND IP.NRPERFACLPAINEL = C_PERFACLPAINEL.NRORIGEM
                              AND P.CDFILIAL = :CDFILIAL
                              AND P.NRORG = :NRORG;
                      
                      FOR C_INDICPAINEL IN (SELECT IP.NRINDICPAINEL, IO.NRINDICPAINEL NRORIGEM
                                              FROM PERFACLPAINEL P, INDICPAINEL IP, PERFACLPAINEL O, INDICPAINEL IO
                                             WHERE IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                               AND P.CDFILIAL = C_LISTA.CDLISTA
                                               AND P.NRORG = :NRORG
                                               AND IO.NRPERFACLPAINEL = O.NRPERFACLPAINEL
                                               AND O.CDFILIAL = :CDFILIAL
                                               --AND IP.NRPERFACLPAINEL = IO.NRPERFACLPAINEL
                                               AND IP.NRINDICADORTF = IO.NRINDICADORTF) LOOP
                          SELECT COUNT(1)
                            INTO V_QUANT
                            FROM PERFACLPAINEL P, INDICPAINEL IP, INDICPAINEXCOPER EX, FILIOPER FO
                           WHERE /* EX.NRINDICPAINEL = IP.NRINDICPAINEL
                             AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                             AND EX.NRINDICPAINEL = C_INDICPAINEL.NRORIGEM
                             AND P.CDFILIAL = :CDFILIAL
                             AND P.NRORG = :NRORG; */
                             EX.NRINDICPAINEL = IP.NRINDICPAINEL
                                  AND EX.NRINDICPAINEL = C_INDICPAINEL.NRORIGEM
                                  AND FO.CDFILIAL = C_LISTA.CDLISTA
                                  AND FO.CDOPERADOR = EX.CDOPERADOR
                                  AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                  AND P.CDFILIAL = :CDFILIAL
                                  AND P.NRORG = :NRORG;
                          
                          NOVO_CODIGO('INDICPAINEXCOPER',V_SEQINDICPAINEXCOPER, V_QUANT);
                          
                          INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                               SELECT V_SEQINDICPAINEXCOPER+ROWNUM-1, C_INDICPAINEL.NRINDICPAINEL, EX.CDOPERADOR, EX.NRORG
                                 FROM PERFACLPAINEL P, INDICPAINEL IP, INDICPAINEXCOPER EX, FILIOPER FO
                                WHERE EX.NRINDICPAINEL = IP.NRINDICPAINEL
                                  AND EX.NRINDICPAINEL = C_INDICPAINEL.NRORIGEM
                                  AND FO.CDFILIAL = C_LISTA.CDLISTA
                                  AND FO.CDOPERADOR = EX.CDOPERADOR
                                  AND IP.NRPERFACLPAINEL = P.NRPERFACLPAINEL
                                  AND P.CDFILIAL = :CDFILIAL
                                  AND P.NRORG = :NRORG;  
                      END LOOP;
                  END LOOP;
                 COMMIT;
               END LOOP;
            END;";
       try {
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);
        } catch (Exception $ex){
            throw $ex;
        }
    }
    
    public function deleteParameterization($params) {
        $queryIndcpainel = "DELETE
                  FROM INDICPAINEL I
                 WHERE I.NRPERFACLPAINEL IN (SELECT NRPERFACLPAINEL
                                               FROM PERFACLPAINEL 
                                              WHERE CDFILIAL <> :CDFILIAL
                                                AND NRORG = :NRORG
                                                AND NRPAINEL = NVL(:NRPAINEL, NRPAINEL)
                                              GROUP BY NRPERFACLPAINEL)";
        $queryPerfaclpainel = "DELETE
                   FROM PERFACLPAINEL
                  WHERE CDFILIAL <> :CDFILIAL
                    AND NRORG = :NRORG
                    AND NRPAINEL = NVL(:NRPAINEL, NRPAINEL)";
        try {
            $stdIndcpainel = $this->connection->prepare($queryIndcpainel);
            $stdPerfaclpainel = $this->connection->prepare($queryPerfaclpainel);
    
            $stdIndcpainel->execute($params);
            $stdPerfaclpainel->execute($params);
        } catch (Exception $e){
            throw $e;
        }                                    
    }
    
    public function deleteUnitsParameterization($params){
        $queryIndcpainel = 
        "DELETE
           FROM INDICPAINEL I
          WHERE I.NRPERFACLPAINEL IN (SELECT P.NRPERFACLPAINEL
                                        FROM PERFACLPAINEL P
                                       WHERE EXISTS (SELECT 1
                                                       FROM LISTA L
                                                      WHERE L.CDLISTA = P.CDFILIAL
                                                        AND L.NRLISTA = :NRLISTA
                                                        AND L.NRORG = :NRORG)
                                         AND P.NRORG = :NRORG
                                         AND P.NRPAINEL = NVL(:NRPAINEL, P.NRPAINEL)
                                       GROUP BY P.NRPERFACLPAINEL)";
        
        $queryPerfaclpainel = 
         "DELETE
            FROM PERFACLPAINEL P
            WHERE EXISTS (SELECT 1
                            FROM LISTA L
                           WHERE L.CDLISTA = P.CDFILIAL
                             AND L.NRLISTA = :NRLISTA
                             AND L.NRORG = :NRORG)
             AND P.NRORG = :NRORG
             AND P.NRPAINEL = NVL(:NRPAINEL, P.NRPAINEL) ";
       try {
            $stdDelete = $this->connection->prepare($queryIndcpainel);
            $stdDelete->execute($params);
            $std = $this->connection->prepare($queryPerfaclpainel);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }

    public function insertAutomaticRegistration($params){
        $query = "
            DECLARE V_QUANT  NUMBER;
                    V_COMMIT              NUMBER;
                    V_SEQPERFACLPAINEL    NUMBER;
                    V_SEQINDICPAINEL      NUMBER;
                    V_SEQINDICPAINEXCOPER NUMBER;
                    V_CDFILIAL            VARCHAR2(04);
            BEGIN
               V_QUANT := 0;
               V_COMMIT := 0;
               V_CDFILIAL := ' ';
               
               IF :UTILIZA_PADRAO = 'S' THEN
                  FOR C_LISTA IN (SELECT FF.CDFILIAL
                                    FROM FILIAL FF
                                   WHERE EXISTS (SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :NRLISTA_UNIDADE
                                                    AND F.CDLISTA = FF.CDFILIAL
                                                  UNION
                                                 SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :NRLISTA_UNIDADE
                                                    AND F.CDLISTA = 'T')) LOOP
            
                     UPDATE PARAMFILIAL
                        SET IDUTLDSBTPADRAO = :UTILIZA_PADRAO
                      WHERE CDFILIAL = C_LISTA.CDFILIAL;
                      
                     COMMIT;
                  END LOOP;
               ELSE
                  FOR C_LISTA IN (SELECT FF.CDFILIAL, P.CDLISTA NRPERFILACESSO
                                    FROM FILIAL FF, LISTA P
                                   WHERE EXISTS (SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :NRLISTA_UNIDADE
                                                    AND F.CDLISTA = FF.CDFILIAL
                                                  UNION
                                                 SELECT 1
                                                   FROM LISTA F
                                                  WHERE F.NRLISTA = :NRLISTA_UNIDADE
                                                    AND F.CDLISTA = 'T')
                                     AND P.NRLISTA = :NRLISTA_PERFIL
                                   UNION 
                                  SELECT 'P' CDFILIAL, P.CDLISTA NRPERFILACESSO
                                    FROM LISTA F, LISTA P
                                   WHERE F.NRLISTA = :NRLISTA_UNIDADE
                                     AND F.CDLISTA = 'P'
                                     AND P.NRLISTA = :NRLISTA_PERFIL
                                   ORDER BY CDFILIAL) LOOP
                      V_SEQINDICPAINEL := 0;
                      
                      IF V_CDFILIAL <> C_LISTA.CDFILIAL AND C_LISTA.CDFILIAL <> 'P' THEN
                         UPDATE PARAMFILIAL
                            SET IDUTLDSBTPADRAO = :UTILIZA_PADRAO
                          WHERE CDFILIAL = C_LISTA.CDFILIAL;
                          
                         V_CDFILIAL := C_LISTA.CDFILIAL;
                      END IF;
                      
                      NOVO_CODIGO('PERFACLPAINEL',V_SEQPERFACLPAINEL);
                      
                      INSERT INTO PERFACLPAINEL (NRPERFACLPAINEL, NRPERFILACESSO, NRPAINEL, CDFILIAL, IDPADRAODASH, NRORG)
                           VALUES (V_SEQPERFACLPAINEL, C_LISTA.NRPERFILACESSO, :PAINEL, C_LISTA.CDFILIAL, 'N', :NRORG);
                      
                      /* Grava nao visiveis */  
                      FOR C_INDICPAINEL IN (SELECT V_SEQPERFACLPAINEL NRPERFACLPAINEL, I.NRINDICADORTF
                                              FROM INDICADORTF I
                                             WHERE I.NRPAINEL = :PAINEL
                                               AND I.NRORG = :NRORG
                                               AND NOT INSTR(:INDICADOR_VISIVEL, '_'||I.NRINDICADORTF||'_') > 0) LOOP
                                               
                                        
                        NOVO_CODIGO('INDICPAINEL',V_SEQINDICPAINEL);
                               
                          INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                               VALUES (V_SEQINDICPAINEL, C_INDICPAINEL.NRPERFACLPAINEL, C_INDICPAINEL.NRINDICADORTF, 'N', :NRORG);
                        
                          IF :NRLISTA_EXCECAO IS NOT NULL THEN
                              SELECT COUNT(1)
                                INTO V_QUANT
                                FROM LISTA  L
                               WHERE L.NRLISTA = :NRLISTA_EXCECAO
                                 AND L.NRORG = :NRORG;
                                      
                              IF V_QUANT > 0 THEN
                                  NOVO_CODIGO('INDICPAINEXCOPER',V_SEQINDICPAINEXCOPER, V_QUANT);
                                          
                                  INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                                       SELECT V_SEQINDICPAINEXCOPER+ROWNUM-1, V_SEQINDICPAINEL, L.CDLISTA, :NRORG
                                         FROM LISTA  L
                                        WHERE L.NRLISTA = :NRLISTA_EXCECAO
                                          AND L.NRORG = :NRORG;
                              END IF;
                          END IF;
                      END LOOP;
                      /*  */
                      IF :NRLISTA_EXCECAO IS NOT NULL THEN
                          FOR C_INDICPAINEL IN (SELECT V_SEQPERFACLPAINEL NRPERFACLPAINEL, I.NRINDICADORTF
                                                  FROM INDICADORTF I
                                                 WHERE I.NRPAINEL = :PAINEL
                                                   AND I.NRORG = :NRORG
                                                   AND INSTR(:INDICADOR_VISIVEL, '_'||I.NRINDICADORTF||'_') > 0) LOOP
                          
                              NOVO_CODIGO('INDICPAINEL',V_SEQINDICPAINEL);
                                   
                              INSERT INTO INDICPAINEL (NRINDICPAINEL, NRPERFACLPAINEL, NRINDICADORTF, IDVISUINDIC, NRORG)
                                   VALUES (V_SEQINDICPAINEL, C_INDICPAINEL.NRPERFACLPAINEL, C_INDICPAINEL.NRINDICADORTF, 'S', :NRORG);
                            
                              IF :NRLISTA_EXCECAO IS NOT NULL THEN
                                  SELECT COUNT(1)
                                    INTO V_QUANT
                                    FROM LISTA  L
                                   WHERE L.NRLISTA = :NRLISTA_EXCECAO
                                     AND L.NRORG = :NRORG;
                                          
                                  IF V_QUANT > 0 THEN
                                      NOVO_CODIGO('INDICPAINEXCOPER',V_SEQINDICPAINEXCOPER, V_QUANT);
                                              
                                      INSERT INTO INDICPAINEXCOPER (NRINDICPAINEXCOPER, NRINDICPAINEL, CDOPERADOR, NRORG)
                                           SELECT V_SEQINDICPAINEXCOPER+ROWNUM-1, V_SEQINDICPAINEL, L.CDLISTA, :NRORG
                                             FROM LISTA  L
                                            WHERE L.NRLISTA = :NRLISTA_EXCECAO
                                              AND L.NRORG = :NRORG;
                                  END IF;
                              END IF;
                          END LOOP;
                      END IF;
                      COMMIT;
                  END LOOP;
               END IF;
            END;";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
}