import {
  Http, IEventParam, Metadata, Loader,
} from '@zeedhi/core';
import { Modal } from '@zeedhi/common';
import { ECharts } from '@zeedhi/zd-echarts-common';
import { TekGrid } from '@zeedhi/teknisa-components-common';

interface OptionalDataChart {
  IDCONFRECEBIMENTO?: string;
  CDOPERADOR?: string;
  REGIAO?: string;
  ESTADO?: string;
  NMESTADO?: string;
}

interface DataChart extends OptionalDataChart {
  LABEL: string;
  VALUE: string | number;
}

interface DataResponse extends OptionalDataChart {
  name: string;
  value: string | number;
}

export class AFGeneralController {
  private gGeneralAFModal!: Modal;
  
  public AFGeneralModal = Loader.getInstance('AFGeneralModalController');
  
  public transformResponseInDataChart(response: DataChart[]) {
    const data = response.map((resp) => {
      const dataResponse: DataResponse = {
        name: resp.LABEL,
        value: resp.VALUE,
      };
      
      if (resp.IDCONFRECEBIMENTO !== undefined) {
        dataResponse.IDCONFRECEBIMENTO = resp.IDCONFRECEBIMENTO;
      }
      
      if (resp.CDOPERADOR !== undefined) {
        dataResponse.CDOPERADOR = resp.CDOPERADOR;
      }
      
      if (resp.REGIAO !== undefined) {
        dataResponse.REGIAO = resp.REGIAO;
      }
      
      if (resp.NMESTADO !== undefined) {
        dataResponse.ESTADO = resp.NMESTADO;
      }
      
      return dataResponse;
    });
    return data;
  }
  
  public getAFGeneralChartData({ component }: IEventParam<ECharts>) {
    const props = component.options.props;
    const routeName = props.routeName;
    Http.get(`/${routeName}?requestType:FilterData`).then(({ data }) => {
      const response = data.dataset.AFGeneral;
      
      const dataToChart = this.transformResponseInDataChart(response);
      // component.options.series.data = dataToChart;
      const options = {
        series: [
          {
            type: 'pie',
            data: [
              ...dataToChart,
            ],
          },
        ],
      };
      component.updateChart(options);
    });
  }
  
  public async callModal({ component }: IEventParam<ECharts>, seriesData) {
    const props = component.options.props;
    const gridRoute = props.gridRoute;
    await this.AFGeneralModal.openAFGeneralModal();
    const gridGroup = Metadata.getInstance<TekGrid>('AFGeneralTAGridGroup');
    gridGroup.title = `${component.options.fullTitle.text} > ${seriesData.name}`;
    
    let queryString = 'requestType=FilterData';
    queryString += `&OPERADOR=${seriesData.CDOPERADOR}`;
    queryString += `&IDCONFRECEBIMENTO=${seriesData.IDCONFRECEBIMENTO}`;
    queryString += `&NMESTADO=${seriesData.ESTADO}`;
    queryString += `&NMREGIAOGEO=${seriesData.REGIAO}`;
    
    Http.get(`/${gridRoute}?${queryString}`).then(({ data }) => {
      gridGroup.datasource.updateData(data.dataset.AFGeneralTAGridGroup);
    });
  }
  
  public drillDown({ component, param }: IEventParam<ECharts>) {
    const drillLevel = component.drillHistory.length;
    const seriesData = param.data;
    let title = '';
    
    if (drillLevel >= 3) {
      return this.callModal({ component }, seriesData);
    }
    
    let queryString = `requestType=FilterData&level=${drillLevel}`;
    if (seriesData.IDCONFRECEBIMENTO !== undefined) {
      queryString += `&IDCONFRECEBIMENTO=${seriesData.IDCONFRECEBIMENTO}`;
    }
    
    if (seriesData.CDOPERADOR !== undefined) {
      queryString += `&operador=${seriesData.CDOPERADOR}`;
    }
    
    if (seriesData.REGIAO !== undefined) {
      queryString += `&regiao=${seriesData.REGIAO}`;
    }
    
    return Http.get(`/drillDownAFGeneral?${queryString}`).then((response) => {
      const dataToChart = this.transformResponseInDataChart(response.data.dataset.drillDownAFGeneral);
      title = seriesData.name;
      component.options.fullTitle.text += `> ${title}`;
      
      const newOptions = {
        title: {
          text: title,
        },
        series: [
          {
            type: 'pie',
            data: [
              ...dataToChart,
            ],
          },
        ],
      };
      component.drillDown(newOptions);
    });
  }
  
  public drillUp() {
  }
}
