import { FormatterParserProvider } from '@zeedhi/core';

export class Utilities {
  formatValue(type: string, value: any): any {
    let valueReturn = '';
    
    if (value !== undefined) {
      const formatterFn = FormatterParserProvider.getFormatter('ZdNumber');

      switch (type) {
        case 'float':
          if ((value || value === 0) && (value < 10000000000000 && value > -10000000000000)) {
            valueReturn = formatterFn(value);
          } else {
            valueReturn = '-';
          }
          break;
        case 'number':
          valueReturn = value || value === 0 ? value.toFixed(0) : '-';
          break;
        case 'date': valueReturn = value ? value.substring(0, 10) : '-';
          break;
        default: valueReturn = value;
      }
    } else {
      valueReturn = value;
    }
    return valueReturn;
  }
  
  formatFilter(obj: any): any {
    const objReturn = Object.entries(obj).map(([name, value]) => ({
      name,
      operator: '=',
      value,
    }));
    
    return objReturn;
  }
  
  lightenColor(color: string, percent: number): string {
    const hex = color.replace('#', '');

    let r = parseInt(hex.substring(0, 2), 16);
    let g = parseInt(hex.substring(2, 4), 16);
    let b = parseInt(hex.substring(4, 6), 16);

    r = Math.floor((255 - r) * (percent / 100) + r);
    g = Math.floor((255 - g) * (percent / 100) + g);
    b = Math.floor((255 - b) * (percent / 100) + b);

    const lightenHex = '#'.concat(((r * 0x10000) + (g * 0x100) + b).toString(16).padStart(6, '0'));

    return lightenHex;
  }
  
  darkenColor(color: string, percent: number): string {
    const hex = color.replace('#', '');

    let r = parseInt(hex.substring(0, 2), 16);
    let g = parseInt(hex.substring(2, 4), 16);
    let b = parseInt(hex.substring(4, 6), 16);

    r = Math.floor(r * (1 - percent / 100));
    g = Math.floor(g * (1 - percent / 100));
    b = Math.floor(b * (1 - percent / 100));

    const darkenHex = '#'.concat(((r * 0x10000) + (g * 0x100) + b).toString(16).padStart(6, '0'));

    return darkenHex;
  }
  
  changeDragHandlerColor() {
    const zdDragHandler = document.querySelectorAll('.draggable-handle');
    zdDragHandler.forEach((element) => {
      let pathElement: any = 0;
      pathElement = element.querySelector('svg path');
      pathElement.setAttribute('fill', '#B2B2B2'); /* #808080 */
    });
  }
  
  public dishMask() {
    const mask = localStorage.getItem('CDPICTPRAT');
    return mask;
  }
  
  public accountingMask() {
    const mask = localStorage.getItem('CDPICTCCTB');
    return mask;
  }
  
  public productMask() {
    const mask = localStorage.getItem('CDPICTPROD');
    return mask;
  }
   
  public formatInscription(value: string) {
    switch (value.length) {
      case 11:
        return '###.###.###-##';
        break;
      case 14:
        return '##.###.###/####-##';
        break;
      default:
        return '';
        break;
    }
  }
}
